pub struct PluginLoader { /* private fields */ }Expand description
Loads a plugin from a shared library (.so / .dylib) file.
The library must export a C-ABI function with the signature:
extern "C" fn create_plugin() -> *mut dyn PluginStep;Implementations
Sourceimpl PluginLoader
impl PluginLoader
pub fn new() -> Self
Sourcepub fn load_plugin(path: &str) -> Result<Box<dyn PluginStep>>
pub fn load_plugin(path: &str) -> Result<Box<dyn PluginStep>>
Load a plugin from the given path.
Safety
Loading and calling foreign functions from shared libraries is inherently unsafe. The caller must ensure the library is a valid minion plugin.