pub struct PluginDef {
pub name: String,
pub path: String,
}Expand description
Definition of a dynamic plugin to load from a shared library
Fields
name: StringName used to reference this plugin as a step type in the workflow YAML
path: StringPath to the shared library file (.so / .dylib)